# Data processing Package

- __init__(files, file_name, is_qme):
```
files: list[UploadFile] default = None
file_name: str default = ''
is_qme: bool default = True
```




This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.